@@ -1,7 +1,7 @@
 import os
 import pytest
 from dotenv import load_dotenv
-from thycotic.secrets.server import PasswordGrantAuthorizer, SecretServerCloud
+from delinea.secrets.server import PasswordGrantAuthorizer, SecretServerCloud
 
 load_dotenv()
 
@@ -13,7 +13,7 @@ def env_vars():
         "password": os.getenv("TSS_PASSWORD"),
         "tenant": os.getenv("TSS_TENANT"),
         "secret_id": os.getenv("SECRET_ID"),
-        "secret_path": os.getenv("SECRET_PATH")
+        "secret_path": os.getenv("SECRET_PATH"),
     }
 
 
